@@ -25,10 +25,6 @@
 
 #define FGL_DEVICE_SIGNATURE    0x10020000
 
-#ifndef KERNEL_VERSION
-#define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
-#endif
-
 #if defined(__i386__) || defined(__x86_64__)
 #define LITTLEENDIAN_CPU 1
 #endif
@@ -72,7 +68,6 @@ do { \
 do { \
     if (!pgd_present(*(pgd_p)))	\
     { \
-        __KE_ERROR("FATAL ERROR: User queue buffer not present! (pgd)\n"); \
         return PAGING_FAULT_SIGBUS_INT;   /* Something bad happened; generate SIGBUS */ \
         /* alternatively we could generate a NOPAGE_OOM "out of memory" */ \
     } \
@@ -85,7 +80,6 @@ do { \
     pud_t *pud_p = pud_offset(pgd_p, pte_linear); \
     if (!pud_present(*(pud_p)))	\
     { \
-        __KE_ERROR("FATAL ERROR: User queue buffer not present! (pud)\n"); \
         return PAGING_FAULT_SIGBUS_INT;   /* Something bad happened; generate SIGBUS */ \
         /* alternatively we could generate a NOPAGE_OOM "out of memory" */ \
     } \
@@ -105,7 +99,6 @@ do { \
 do { \
     if (!pmd_present(*(pmd_p)))	\
     { \
-        __KE_ERROR("FATAL ERROR: User queue buffer not present! (pmd)\n"); \
         return PAGING_FAULT_SIGBUS_INT;   /* Something bad happened; generate SIGBUS */ \
         /* alternatively we could generate a NOPAGE_OOM "out of memory" */ \
     } \
@@ -151,7 +144,6 @@ do { \
 do { \
     if (!pte_present(pte)) \
     { \
-        __KE_ERROR("FATAL ERROR: User queue buffer not present! (pte)\n"); \
         return PAGING_FAULT_SIGBUS_INT;   /* Something bad happened; generate SIGBUS */ \
         /* alternatively we could generate a NOPAGE_OOM "out of memory" */ \
     } \
@@ -174,10 +166,6 @@ do { \
 #define PM_EVENT_SUSPEND 3
 #endif
 
-#if defined(CONFIG_COMPAT) && LINUX_VERSION_CODE > KERNEL_VERSION(2,6,9)
-#define FIREGL_IOCTL_COMPAT
-#endif
-
 /*****************************************************************************/
 
 struct vm_area_struct;
@@ -185,10 +173,6 @@ struct semaphore;
 struct drm_device;
 struct firegl_pcie_mem;
 
-#if !defined(ATI_API_CALL)
-#define ATI_API_CALL __attribute__((regparm(0)))
-#endif
-
 /*****************************************************************************/
 
 typedef unsigned long __ke_dev_t;
@@ -208,8 +192,6 @@ typedef unsigned long long __ke_dma_addr_t;
 typedef long long __ke_loff_t;
 
 // note: assigning uniqe types to originally non interchangeable types
-typedef struct { int uniqe1; } __ke_wait_queue_head_t;
-typedef struct { int uniqe2; } __ke_wait_queue_t;
 typedef struct { int uniqe3; } __ke_sigset_t;
 typedef struct { int uniqe7; } __ke_file_operations_t;
 
@@ -222,7 +204,7 @@ typedef struct {
     __ke_file_operations_t* fops;
 } __ke_proc_list_t;
 
-extern __ke_proc_list_t firegl_proc_list[];
+extern __ke_proc_list_t KCL_PROC_FileList[];
 
 typedef struct {
     unsigned long           signature;
@@ -311,6 +293,15 @@ typedef enum
     KCL_KERNEL_CONF_PARAM_NUM
 } KCL_ENUM_KernelConfigParam;
 
+
+typedef struct {
+	unsigned long totalram;		// Total usable main memory size 
+	unsigned long freeram;		// Available memory size (low memory)
+	unsigned long totalhigh;	// Total high memory size
+	unsigned long freehigh;		// Available high memory size 
+	unsigned int mem_unit;		// Memory unit size in bytes 
+}KCL_SYS_MEM_INFO;
+
 /** KCL function declarations */
 
 extern void          ATI_API_CALL KCL_GlobalKernelScheduler(void);
@@ -326,6 +317,11 @@ extern void          ATI_API_CALL KCL_DelayInMicroSeconds(unsigned long usecs);
 extern void          ATI_API_CALL KCL_DelayUseTSC(unsigned long usecs);
 extern unsigned long ATI_API_CALL KCL_ConvertAddressVirtualToBus(void* address);
 extern unsigned long ATI_API_CALL KCL_ConvertAddressVirtualToPhysical(void* address);
+
+extern unsigned long ATI_API_CALL KCL_ConvertPageToPfn(void* page);
+extern void*         ATI_API_CALL KCL_ConvertPageToKernelAddress(void* page);
+extern unsigned int  ATI_API_CALL KCL_IsPageInHighMem(void* page);
+
 extern void*         ATI_API_CALL KCL_GetHighMemory(void);
 extern int           ATI_API_CALL KCL_GetErrorCode(KCL_ENUM_ErrorCode errcode);
 extern void          ATI_API_CALL KCL_GlobalKernelLock(void);
@@ -333,12 +329,14 @@ extern void          ATI_API_CALL KCL_GlobalKernelUnlock(void);
 extern int           ATI_API_CALL KCL_PosixSecurityCapCheck(KCL_ENUM_PosixSecurityCap cap);
 extern void          ATI_API_CALL KCL_PosixSecurityCapSetIPCLock(unsigned int lock);
 extern unsigned long ATI_API_CALL KCL_GetAvailableRamPages(void);
+extern void          ATI_API_CALL KCL_GetSystemMemInfo(KCL_SYS_MEM_INFO* info);
 extern void          ATI_API_CALL KCL_ReserveMemPage(void* pt);
 extern void          ATI_API_CALL KCL_UnreserveMemPage(void* pt);
 extern void          ATI_API_CALL KCL_LockMemPage(void* pt);
 extern void          ATI_API_CALL KCL_UnlockMemPage(void* pt);
 extern int           ATI_API_CALL KCL_KernelConfigParamIsDefined(KCL_ENUM_KernelConfigParam param);
 extern int           ATI_API_CALL KCL_SetPageCache(void* virt, int pages,int enable);
+extern int           ATI_API_CALL KCL_SetPageCache_Array(unsigned long *pt, int pages, int enable);
 extern void          ATI_API_CALL KCL_AtomicInc(KCL_TYPE_Atomic* v);
 extern void          ATI_API_CALL KCL_AtomicDec(KCL_TYPE_Atomic* v);
 extern void          ATI_API_CALL KCL_AtomicAdd(KCL_TYPE_Atomic* v, int val);
@@ -418,27 +416,15 @@ extern unsigned long ATI_API_CALL firegl_get_pcie_pageaddr_from_vm(  struct vm_a
 extern void* ATI_API_CALL firegl_get_pagelist_from_vm(  struct vm_area_struct* vma );
 extern unsigned long ATI_API_CALL firegl_get_addr_from_vm(  struct vm_area_struct* vma);
 extern unsigned long ATI_API_CALL firegl_get_pagetable_page_from_vm(struct vm_area_struct* vma);
-extern unsigned long ATI_API_CALL mc_heap_get_page_addr(void *vma, unsigned long offset);
+extern void* ATI_API_CALL mc_heap_get_page(void *vma, unsigned long long offset);
 
 /*****************************************************************************/
 
-extern __ke_wait_queue_head_t* ATI_API_CALL __ke_alloc_wait_queue_head_struct(void);
-extern void ATI_API_CALL __ke_free_wait_queue_head_struct(__ke_wait_queue_head_t* queue_head);
-extern __ke_wait_queue_t* ATI_API_CALL __ke_alloc_wait_queue_struct(void);
-extern void ATI_API_CALL __ke_free_wait_queue_struct(__ke_wait_queue_t* queue);
-
-extern void ATI_API_CALL __ke_wait_event_interruptible(__ke_wait_queue_head_t* queue_head, int condition);
-extern void ATI_API_CALL __ke_wake_up_interruptible(__ke_wait_queue_head_t* queue_head);
-    
-extern void ATI_API_CALL __ke_add_wait_queue(__ke_wait_queue_head_t* queue_head, __ke_wait_queue_t* entry);
-extern void ATI_API_CALL __ke_remove_wait_queue(__ke_wait_queue_head_t* queue_head, __ke_wait_queue_t* entry);
-extern void ATI_API_CALL __ke_init_waitqueue_head(__ke_wait_queue_head_t* queue_head);
-
-extern void ATI_API_CALL __ke_configure_sigmask(__ke_sigset_t *pSigMask);
+extern void ATI_API_CALL KCL_SIGNAL_ConfigureMask(__ke_sigset_t *pSigMask);
 extern int ATI_API_CALL firegl_sig_notifier(void *priv);
-extern int              firegl_sig_notifier_wrap(void *priv);
-extern void ATI_API_CALL __ke_block_all_signals(int (*notifier)(void *priv), void *pPriv, __ke_sigset_t *pSigMask);
-extern void ATI_API_CALL __ke_unblock_all_signals(void);
+extern int              KCL_SIGNAL_Notifier(void *priv);
+extern void ATI_API_CALL KCL_SIGNAL_BlockAll(int (*notifier)(void *priv), void *pPriv, __ke_sigset_t *pSigMask);
+extern void ATI_API_CALL KCL_SIGNAL_UnblockAll(void);
 
 extern unsigned long ATI_API_CALL __ke__cmpxchg(volatile void *ptr, unsigned long old,                      
                       unsigned long new, int size);
@@ -448,88 +434,75 @@ extern unsigned long ATI_API_CALL __ke__cmpxchg(volatile void *ptr, unsigned lon
                  (unsigned long)(n),sizeof(*(ptr))))
 /*****************************************************************************/
 
-extern __ke_dev_t ATI_API_CALL __ke_getdevice(__ke_device_t *dev);
+extern __ke_dev_t ATI_API_CALL KCL_DEVICE_GetNumber(__ke_device_t *dev);
 
-extern void ATI_API_CALL __ke_mod_inc_use_count(void);
-extern void ATI_API_CALL __ke_mod_dec_use_count(void);
+extern void ATI_API_CALL KCL_MODULE_IncUseCount(void);
+extern void ATI_API_CALL KCL_MODULE_DecUseCount(void);
 
-extern void ATI_API_CALL __ke_down_struct_sem(__ke_device_t *dev, int idx);
-extern void ATI_API_CALL __ke_up_struct_sem(__ke_device_t *dev, int idx);
+extern void ATI_API_CALL KCL_SEMAPHORE_STATIC_Down(__ke_device_t *dev, int idx);
+extern void ATI_API_CALL KCL_SEMAPHORE_STATIC_Up(__ke_device_t *dev, int idx);
 #define __KE_MAX_SEMAPHORES 4
-extern void ATI_API_CALL __ke_sema_init(struct semaphore* sem, int value);
-extern __ke_size_t ATI_API_CALL __ke_sema_size(void);
-extern void ATI_API_CALL __ke_down(struct semaphore* sem);
-extern void ATI_API_CALL __ke_up(struct semaphore* sem);
+extern void ATI_API_CALL KCL_SEMAPHORE_Init(struct semaphore* sem, int value);
+extern __ke_size_t ATI_API_CALL KCL_SEMAPHORE_GetObjSize(void);
+extern void ATI_API_CALL KCL_SEMAPHORE_DownUninterruptible(struct semaphore* sem);
+extern void ATI_API_CALL KCL_SEMAPHORE_Up(struct semaphore* sem);
 
 //PPLIB adding interruptible down for semaphore
-extern int ATI_API_CALL __ke_down_interruptible(struct semaphore* sem);
+extern int ATI_API_CALL KCL_SEMAPHORE_DownInterruptible(struct semaphore* sem);
 //PPLIB end
 
-extern void ATI_API_CALL __ke_spin_lock(__ke_device_t *dev, int ndx);
-extern void ATI_API_CALL __ke_spin_unlock(__ke_device_t *dev, int ndx);
-	#define __KE_MAX_SPINLOCKS 7
+extern void ATI_API_CALL KCL_SPINLOCK_STATIC_Grab(__ke_device_t *dev, int ndx);
+extern void ATI_API_CALL KCL_SPINLOCK_STATIC_Release(__ke_device_t *dev, int ndx);
+	#define __KE_MAX_SPINLOCKS 8
 
 int ATI_API_CALL __ke_vsprintf(char *buf, const char *fmt, va_list ap);
 int ATI_API_CALL __ke_vsnprintf(char *buf, size_t size, const char *fmt, va_list ap);
 
-extern void ATI_API_CALL __ke_printk(const char* fmt, ...);
-
-#ifdef __x86_64__
-extern void* ATI_API_CALL KCL_AMD64_COMPAT32_AllocUserSpace(long size);
-#endif
 extern int ATI_API_CALL KCL_CopyFromUserSpace(void* to, const void* from, __ke_size_t size);
 extern int ATI_API_CALL KCL_CopyToUserSpace(void* to, const void* from, __ke_size_t size);
 
-extern void* ATI_API_CALL __ke_malloc(__ke_size_t size);
-extern void* ATI_API_CALL __ke_malloc_atomic(__ke_size_t size);
-extern void ATI_API_CALL __ke_free(void* p);
-extern void ATI_API_CALL __ke_free_s(void* p, __ke_size_t size);
+extern void* ATI_API_CALL KCL_MEM_SmallBufferAlloc(__ke_size_t size);
+extern void* ATI_API_CALL KCL_MEM_SmallBufferAllocAtomic(__ke_size_t size);
+extern void ATI_API_CALL KCL_MEM_SmallBufferFree(void* p);
 extern void* ATI_API_CALL __ke_vmalloc(__ke_size_t size);
-extern void* ATI_API_CALL __ke_vmalloc_32(__ke_size_t size);
-extern void* ATI_API_CALL __ke_vmalloc_atomic(__ke_size_t size);
-extern void ATI_API_CALL __ke_vfree(void* p);
-extern void* ATI_API_CALL __ke_get_free_page(void);
-extern void* ATI_API_CALL __ke_get_free_pages(int order);
-extern void ATI_API_CALL __ke_free_page(void* pt);
-extern void ATI_API_CALL __ke_free_pages(void* pt, int order);
-extern void ATI_API_CALL __ke_get_page(void* pt);
-extern void ATI_API_CALL __ke_put_page(void* pt);
-extern int ATI_API_CALL __ke_verify_read_access(void* addr, __ke_size_t size);
-extern int ATI_API_CALL __ke_verify_write_access(void* addr, __ke_size_t size);
-extern unsigned long ATI_API_CALL KCL_GetPageTableByVirtAddr(unsigned long virtual_addr, unsigned long* page_addr, int* is_highpte);
-extern void ATI_API_CALL __ke_put_vm_page_table(unsigned long page_addr);
+extern void* ATI_API_CALL KCL_MEM_Alloc(__ke_size_t size);
+extern void* ATI_API_CALL KCL_MEM_AllocAtomic(__ke_size_t size);
+extern void ATI_API_CALL KCL_MEM_Free(void* p);
+extern void* ATI_API_CALL KCL_MEM_AllocPageFrame(void);
+extern void* ATI_API_CALL KCL_MEM_AllocContiguousPageFrames(int order);
+extern void ATI_API_CALL KCL_MEM_FreePageFrame(void* pt);
+extern void ATI_API_CALL KCL_MEM_FreePageFrames(void* pt, int order);
+
+extern void* ATI_API_CALL KCL_MEM_AllocPageForGart(void);
+extern void ATI_API_CALL KCL_MEM_FreePageForGart(void* pt);
+
+extern void ATI_API_CALL KCL_MEM_IncPageUseCount(void* pt);
+extern void ATI_API_CALL KCL_MEM_DecPageUseCount(void* pt);
+extern int ATI_API_CALL KCL_MEM_VerifyReadAccess(void* addr, __ke_size_t size);
+extern int ATI_API_CALL KCL_MEM_VerifyWriteAccess(void* addr, __ke_size_t size);
+extern unsigned long ATI_API_CALL KCL_GetPageTableByVirtAddr(unsigned long virtual_addr, unsigned long* page_addr);
 extern __ke_dma_addr_t ATI_API_CALL KCL_GetDmaPhysAddr(unsigned long virtual_addr);
-extern void* ATI_API_CALL __ke_memset(void* s, int c, __ke_size_t count);
-extern void* ATI_API_CALL __ke_memcpy(void* d, const void* s, __ke_size_t count);
-extern ATI_API_CALL __ke_size_t __ke_strlen(const char *s);
-extern char* ATI_API_CALL __ke_strcpy(char* d, const char* s);
-extern char* ATI_API_CALL __ke_strncpy(char* d, const char* s, __ke_size_t count);
-extern int ATI_API_CALL __ke_strcmp(const char *s1, const char *s2);
-extern int ATI_API_CALL __ke_strncmp(const char* str1, const char* str2, __ke_size_t count);
-extern int ATI_API_CALL __ke_strnicmp(const char* str1, const char* str2, __ke_size_t count);
-extern char* ATI_API_CALL __ke_strchr(const char *s, int c);
-extern int ATI_API_CALL __ke_sprintf(char* buf, const char* fmt, ...);
-extern int ATI_API_CALL __ke_snprintf(char* buf, size_t size, const char* fmt, ...);
 extern int ATI_API_CALL KCL_TestAndClearPageDirtyFlag(unsigned long virtual_addr);
-extern unsigned long ATI_API_CALL __ke_do_mmap(KCL_IO_FILE_Handle  file, unsigned long addr, unsigned long len, unsigned long pgoff);
-extern int ATI_API_CALL __ke_do_munmap(unsigned long addr, unsigned long len);
-extern void* ATI_API_CALL __ke_vmap(unsigned long *pagelist, unsigned int count);
+extern unsigned long ATI_API_CALL KCL_MEM_AllocLinearAddrInterval(KCL_IO_FILE_Handle  file, unsigned long addr, unsigned long len, unsigned long pgoff);
+extern int ATI_API_CALL KCL_MEM_ReleaseLinearAddrInterval(unsigned long addr, unsigned long len);
+extern void* ATI_API_CALL KCL_MEM_MapPageList(unsigned long *pagelist, unsigned int count);
 #ifdef FIREGL_USWC_SUPPORT
-extern void* ATI_API_CALL KCL_vmap_wc(unsigned long *pagelist, unsigned int count);
+extern void* ATI_API_CALL KCL_MEM_MapPageListWc(unsigned long *pagelist, unsigned int count);
 #endif
-extern void ATI_API_CALL __ke_vunmap(void* addr);
+extern void ATI_API_CALL KCL_MEM_Unmap(void* addr);
 extern unsigned long ATI_API_CALL KCL_GetInitKerPte(unsigned long address);
 
 
 /*****************************************************************************/
 
-extern int ATI_API_CALL __ke_flush_cache(void);
+extern int ATI_API_CALL KCL_MEM_FlushCpuCaches(void);
+extern void ATI_API_CALL KCL_PageCache_Flush(void);
 
 /*****************************************************************************/
 
-extern int ATI_API_CALL __ke_config_mtrr(void);
-extern int ATI_API_CALL __ke_mtrr_add_wc(unsigned long base, unsigned long size);
-extern int ATI_API_CALL __ke_mtrr_del(int reg, unsigned long base, unsigned long size);
+extern int ATI_API_CALL KCL_MEM_MTRR_Support(void);
+extern int ATI_API_CALL KCL_MEM_MTRR_AddRegionWc(unsigned long base, unsigned long size);
+extern int ATI_API_CALL KCL_MEM_MTRR_DeleteRegion(int reg, unsigned long base, unsigned long size);
 
 extern int ATI_API_CALL KCL_is_pat_enabled(void);
 
@@ -540,10 +513,10 @@ extern void ATI_API_CALL KCL_UninstallInterruptHandler(unsigned int irq, void *c
 
 /*****************************************************************************/
 
-extern void* ATI_API_CALL __ke_vma_file_priv(struct vm_area_struct* vma);
-extern unsigned long ATI_API_CALL __ke_vm_start(struct vm_area_struct* vma);
-extern unsigned long ATI_API_CALL __ke_vm_end(struct vm_area_struct* vma);
-extern unsigned long ATI_API_CALL __ke_vm_offset(struct vm_area_struct* vma);
+extern void* ATI_API_CALL KCL_MEM_VM_GetRegionFilePrivateData(struct vm_area_struct* vma);
+extern unsigned long ATI_API_CALL KCL_MEM_VM_GetRegionStart(struct vm_area_struct* vma);
+extern unsigned long ATI_API_CALL KCL_MEM_VM_GetRegionEnd(struct vm_area_struct* vma);
+extern unsigned long ATI_API_CALL KCL_MEM_VM_GetRegionMapOffset(struct vm_area_struct* vma);
 enum __ke_vm_maptype
 {
     __KE_ADPT,
@@ -558,45 +531,18 @@ enum __ke_vm_maptype
     __KE_GART_CACHEABLE,
     __KE_ADPT_REG
 };
-extern char* ATI_API_CALL __ke_vm_flags_str(struct vm_area_struct* vma, char* buf);
-extern char* ATI_API_CALL __ke_vm_page_prot_str(struct vm_area_struct* vma, char* buf);
-extern char* ATI_API_CALL __ke_vm_phys_addr_str(struct vm_area_struct* vma, 
+extern char* ATI_API_CALL KCL_MEM_VM_GetRegionFlagsStr(struct vm_area_struct* vma, char* buf);
+extern char* ATI_API_CALL KCL_MEM_VM_GetRegionProtFlagsStr(struct vm_area_struct* vma, char* buf);
+extern char* ATI_API_CALL KCL_MEM_VM_GetRegionPhysAddrStr(struct vm_area_struct* vma,
                                    char* buf, 
                                    unsigned long linear_address, 
                                    __ke_dma_addr_t* phys_address);
-extern int ATI_API_CALL __ke_vm_map(KCL_IO_FILE_Handle filp,
+extern int ATI_API_CALL KCL_MEM_VM_MapRegion(KCL_IO_FILE_Handle filp,
                                     struct vm_area_struct* vma,
-                                    unsigned long offset,
+                                    unsigned long long offset,
                                     enum __ke_vm_maptype type,
                                     int readonly);
 
-#ifdef __x86_64__
-/*
-typedef int (*__ke_ioctl_trans_handler_t)(unsigned int, unsigned int,
-                                          unsigned long, KCL_IO_FILE_Handle );
-*/
-extern int ATI_API_CALL __ke_register_ioctl32_conversion(unsigned int cmd, int (*handler)(unsigned int, unsigned int, unsigned long, KCL_IO_FILE_Handle));
-extern void ATI_API_CALL __ke_unregister_ioctl32_conversion(unsigned int cmd);
-#endif
-
-/*****************************************************************************/
-
-#ifdef __x86_64__
-
-int ATI_API_CALL firegl_get_user_ptr(__ke_u32 *src,   void **dst);
-int ATI_API_CALL firegl_get_user_u16(__ke_u16 *src,   __ke_u16 *dst);
-int ATI_API_CALL firegl_get_user_u32(__ke_u32 *src,   __ke_u32 *dst);
-int ATI_API_CALL firegl_get_user_u64(__ke_u32 *src,   __ke_u64 *dst);
-
-int ATI_API_CALL firegl_put_user_ptr(void *src,      __ke_u32 *dst);
-int ATI_API_CALL firegl_put_user_u16(__ke_u16 src,   __ke_u16 *dst);
-int ATI_API_CALL firegl_put_user_u32(__ke_u32 src,   __ke_u32 *dst);
-int ATI_API_CALL firegl_put_user_u64(__ke_u64 src,   __ke_u32 *dst);
-int ATI_API_CALL firegl_init_32compat_ioctls(void);
-void ATI_API_CALL firegl_kill_32compat_ioctls(void);
-
-#endif
-
 /*****************************************************************************/
 
 extern int ATI_API_CALL firegl_pci_save_state(KCL_PCI_DevHandle pdev, struct drm_device* dev);
@@ -613,57 +559,19 @@ extern void ATI_API_CALL firegl_pm_enable_interrupts(struct drm_device* dev);
 
 /*****************************************************************************/
 
-extern int ATI_API_CALL fgldbg_register_sysrq(int);
-extern int ATI_API_CALL fgldump_register_sysrq(int);
-
-/*****************************************************************************/
-
-/* globals */
-extern int __ke_debuglevel;
-#define DEBUGFLAG_NO_HW_ACCESS  0x00020000
-#define DEBUGLEVEL_MASK         0x0000ffff
-#define debuglevel              (__ke_debuglevel &  DEBUGLEVEL_MASK)
-
-extern int __ke_moduleflags;
-
-/* module flags*/
-#define __KE_FLAG_DEBUG                     0x00000001
-#define __KE_FLAG_NOAUTH                    0x00000002
-#define __KE_FLAG_DISABLE_FIREGL_AGPLOCK    0x00000010
-#define __KE_FLAG_DISABLE_DYNAMIC_PCIE      0x00000020
-#define __KE_FLAG_DISABLE_USWC              0x00000040
-
 /* global constants */
-extern const char*          __ke_UTS_RELEASE;
-extern const unsigned long  __ke_LINUX_VERSION_CODE;
-extern const unsigned int   __ke_PAGE_SHIFT;
-extern const unsigned int   __ke_PAGE_SIZE;
-extern const unsigned long  __ke_PAGE_MASK;
+extern const char*          KCL_SYSINFO_OsVersionString;
+extern const unsigned long  KCL_SYSINFO_OsVersionCode;
+extern const unsigned int   KCL_SYSINFO_PageSize;
 
-extern const unsigned long  __ke_MODVERSIONS_State;
-extern const unsigned long  __ke_SMP_State;
-extern const unsigned long  __ke_PAE_State;
+extern const unsigned long  KCL_SYSINFO_BinaryModuleSupport;
+extern const unsigned long  KCL_SYSINFO_SmpSupport;
+extern const unsigned long  KCL_SYSINFO_PaeSupport;
 
 /* global vars that are in fact constants */
-extern unsigned long        __ke_HZ;
+extern unsigned long        KCL_SYSINFO_TimerTicksPerSecond;
 
 /*****************************************************************************/
-/* Macros to make printk easier */
-#define __KE_ERROR(fmt, arg...)                                             \
-    __ke_printk("<3>[fglrx:%s] *ERROR* " fmt, __FUNCTION__, ##arg)
-
-#define __KE_INFO(fmt, arg...)                                              \
-    __ke_printk("<6>[fglrx] " fmt, ##arg)
-
-#define __KE_DEBUG0(fmt, arg...)                                            \
-    do                                                                      \
-    {                                                                       \
-        if (debuglevel > 0)                                                 \
-        {                                                                   \
-            __ke_printk("<7>[fglrx:%s] " fmt , __FUNCTION__, ##arg);        \
-        }                                                                   \
-    } while (0)
-/*****************************************************************************/
 
 #ifndef __GFP_COMP
 #define __GFP_COMP 0
@@ -843,9 +751,9 @@ extern  long ATI_API_CALL KAS_ScheduleTimeout(long n_jiffies);
 #define FIREGL_ASYNCIO_MAX_FILE     32   /* Currently hardcode to 32 */
 #define FIREGL_ASYNCIO_MAX_SEMA     ((FIREGL_ASYNCIO_MAX_FILE+1)*FIREGL_ASYNCIO_MAX_DEV)
 
-extern void * ATI_API_CALL __ke_asyncio_alloc_sema(void);
-extern void ATI_API_CALL __ke_asyncio_free_sema(struct semaphore *pSema);
-extern void ATI_API_CALL __ke_asyncio_init_sema(void);
+extern void * ATI_API_CALL KCL_SEMAPHORE_ASYNCIO_Alloc(void);
+extern void ATI_API_CALL KCL_SEMAPHORE_ASYNCIO_Free(struct semaphore *pSema);
+extern void ATI_API_CALL KCL_SEMAPHORE_ASYNCIO_Init(void);
 
 typedef enum {
     __KE_POLLIN = 0,
@@ -858,7 +766,7 @@ typedef enum {
     __KE_EINTR
 } __ke_asynio_contant_t;
 
-extern int ATI_API_CALL __ke_getConstant(int contant);
+extern int ATI_API_CALL KCL_SYSINFO_MapConstant(int contant);
 
 extern __ke_ssize_t ATI_API_CALL firegl_asyncio_read( KCL_IO_FILE_Handle filp,
                                                       char *buf, 
@@ -883,6 +791,8 @@ extern void ATI_API_CALL KCL_lock_deinit(void *plock);
 extern void ATI_API_CALL KCL_spin_lock(void *lock);
 extern void ATI_API_CALL KCL_spin_unlock(void *lock);
 extern void ATI_API_CALL KCL_get_random_bytes(void *buf, int nbytes);
+extern void* ATI_API_CALL KCL_get_pubdev(void);
+
 extern void ATI_API_CALL adapter_chain_init(void);
 extern void ATI_API_CALL adapter_chain_cleanup(void);
 extern void ATI_API_CALL cf_object_init(void);
@@ -892,105 +802,8 @@ extern void ATI_API_CALL firegl_cleanup_device_heads(void);
 extern int ATI_API_CALL firegl_get_dev(void *pubdev, KCL_PCI_DevHandle pdev);
 extern void *ATI_API_CALL firegl_find_device(int minor);
 extern void* ATI_API_CALL firegl_query_pcidev(KCL_PCI_DevHandle pdev);
-
-extern void* ATI_API_CALL KCL_get_pubdev(void);
-extern void ATI_API_CALL KCL_dump_stack(void);
-/*******************************************************/
-extern int ATI_API_CALL firegl_dbg_stub(__ke_device_t *pubdev);
-extern void ATI_API_CALL firegl_dump(__ke_device_t *pubdev);
-
-//Add functions need to be traced
-typedef enum
-{
-    FN_FIREGL_OPEN_RELEASE = 0,
-    FN_FIREGL_IOCTL,
-    FN_FIREGL_MMAP,
-    FN_FIREGL_READ_WRITE,
-    FN_FIREGL_FASYNC,
-    FN_FIREGL_POLL,
-    FN_FIREGL_LSEEK,
-    FN_FIREGL_COMPAT_IOCTL,
-    FN_DRM_VM_OPEN_CLOSE,
-    FN_DRM_NOPAGE,
-    FN_FIREGL_ACPI,
-    FN_FIREGL_IRQ,
-    FN_FIREGL_PROC,
-    FN_FIREGL_KAS,
-    FN_FIREGL_KCL,
-    FN_FIREGL_INIT,
-    FN_GENERIC1,
-    FN_GENERIC2,
-    FN_GENERIC3,                      //Added more if necessary  
-    FN_FIREGL_RESERVED =0x20,         //0x20 -0x3f reserverd 
-    FN_GENERIC_MAXIMUM  = 0x3f
-} FN_TRACE;
-
-typedef enum
-{
-    FN_DEBUG_TRACE = 0,
-    FN_DEBUG_LEVEL1,
-    FN_DEBUG_LEVEL2,
-    FN_DEBUG_LEVEL3,
-    FN_DEBUG_LEVEL4,
-    FN_DEBUG_LEVEL5,
-    FN_DEBUG_LEVEL6,
-    FN_DEBUG_LEVEL7,
-    FN_DEBUG_MAXIMUM  = 0x8
-} FN_DEBUG;
-
-#define FN_DEBUG_LEVEL_ALL 0xff
-
-extern void ATI_API_CALL firegl_trace(unsigned int traceMask, unsigned int debugMask, void* name, int line, long param, const char* fmt, ...);
-
-#define __KE_TRACE(_m, _p, fmt, arg...)                                                                     \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_TRACE, (void *)__FUNCTION__ , (int)(__LINE__), (long)(_p), fmt, ##arg);   \
-    } while (0)
-
-
-#define __KE_DEBUG(_m, fmt, arg...)                                                                         \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL1, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);          \
-    } while (0)
-
-#define __KE_DEBUG2(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL2, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)
-
-#define __KE_DEBUG3(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL3, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)
-
-#define __KE_DEBUG4(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL4, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)
-
-#define __KE_DEBUG5(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL5, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)
-
-#define __KE_DEBUG6(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL6, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)    
-
-#define __KE_DEBUG7(_m, fmt, arg...)                                                                        \
-    do                                                                                                      \
-    {                                                                                                       \
-        firegl_trace(_m, FN_DEBUG_LEVEL7, (void *)__FUNCTION__ , (int)__LINE__, 0, fmt, ##arg);             \
-    } while (0)    
-
-/***********************************************************/
+extern int ATI_API_CALL firegl_init_32compat_ioctls(void);
+extern void ATI_API_CALL firegl_kill_32compat_ioctls(void);
+extern int ATI_API_CALL firegl_uswc_user_disabled(void);
 
 #endif /* _FIREGL_PUBLIC_H_ */
